summaryrefslogtreecommitdiff
path: root/Source/Core
diff options
context:
space:
mode:
Diffstat (limited to 'Source/Core')
-rw-r--r--Source/Core/UICommon/UICommon.cpp25
1 files changed, 20 insertions, 5 deletions
diff --git a/Source/Core/UICommon/UICommon.cpp b/Source/Core/UICommon/UICommon.cpp
index eb060b27a3..423fe2d0ea 100644
--- a/Source/Core/UICommon/UICommon.cpp
+++ b/Source/Core/UICommon/UICommon.cpp
@@ -160,6 +160,7 @@ void SetUserDirectory(const std::string& custom_path)
// Make sure it ends in DIR_SEP.
if (*user_path.rbegin() != DIR_SEP_CHR)
user_path += DIR_SEP;
+
#else
if (File::Exists(ROOT_DIR DIR_SEP USERDATA_DIR))
{
@@ -167,6 +168,7 @@ void SetUserDirectory(const std::string& custom_path)
}
else
{
+ const char* env_path = getenv("DOLPHIN_EMU_USERPATH");
const char* home = getenv("HOME");
if (!home)
home = getenv("PWD");
@@ -175,14 +177,23 @@ void SetUserDirectory(const std::string& custom_path)
std::string home_path = std::string(home) + DIR_SEP;
#if defined(__APPLE__) || defined(ANDROID)
- user_path = home_path + DOLPHIN_DATA_DIR DIR_SEP;
+ if (env_path)
+ {
+ user_path = env_path;
+ }
+ else
+ {
+ user_path = home_path + DOLPHIN_DATA_DIR DIR_SEP;
+ }
#else
- // We are on a non-Apple and non-Android POSIX system, there are 3 cases:
+ // We are on a non-Apple and non-Android POSIX system, there are 4 cases:
// 1. GetExeDirectory()/portable.txt exists
// -> Use GetExeDirectory/User
// 2. ~/.dolphin-emu directory exists
// -> Use ~/.dolphin-emu
- // 3. Default
+ // 4. Default
// -> Use XDG basedir, see
// http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
user_path = home_path + "." DOLPHIN_DATA_DIR DIR_SEP;
@@ -191,6 +202,10 @@ void SetUserDirectory(const std::string& custom_path)
{
user_path = exe_path + DIR_SEP "User" DIR_SEP;
}
+ else if (env_path)
+ {
+ user_path = env_path;
+ }
else if (!File::Exists(user_path))
{
const char* data_home = getenv("XDG_DATA_HOME");
@@ -175,14 +177,23 @@ void SetUserDirectory(const std::string& custom_path)
// 1. GetExeDirectory()/portable.txt exists
- // -> Use GetExeDirectory/User
- // 2. ~/.dolphin-emu directory exists
+ // -> Use GetExeDirectory()/User
+ // 2. $DOLPHIN_EMU_USERPATH is set
+ // -> Use $DOLPHIN_EMU_USERPATH
+ // 3. ~/.dolphin-emu directory exists
// -> Use ~/.dolphin-emu